## Projects Using hstrat

*We'd love to show off your project!
To be listed, [make a pull request](https://github.com/mmore500/hstrat/pulls), [open an issue](https://github.com/mmore500/hstrat/issues), or send an email to [m.more500@gmail.com](mailto:m.more500@gmail.com).*

* [DISHTINY: A Platform for Studying Open-Ended Evolutionary Transitions in Individuality](https://github.com/mmore500/dishtiny)
